---
template: mainpanel
source_form: markdown
name: Trello Cardlist Paused
updated: October 2016
title: Trello Cardlist Paused
---
### Paused

* 227\. .get_type() should be delegated, not rely on internal pynode details.
* Flesh out a micro:bit profile.
